@@ -2,7 +2,7 @@
 
 use Devel::Peek qw(:ALL);
 
-$x = [0, 1, {'two' => 22, 2 => 222}, [3, "three"]];
+$x = [0, 1, {'two' => 22, 2 => 222}, [3, "three", [3,3,3], { three => 'iii'}]];
 
 Dump $x;
 print STDERR "Refcount of \$x is ", SvREFCNT($x), "\n";
@@ -25,6 +25,7 @@ sub prototyped (&@) {'aha'}
 
 mstat("Point 1");
 
+Dump(*subr);
 Dump($sub);
 Dump($closure);
 Dump(\&subr);
@@ -34,7 +35,8 @@ Dump(\&other::package);
 Dump(\&prototyped);
 Dump(\&Dump);
 Dump ($x, 10);
+DumpArray (10, 1,2,3);
 
 mstat("Point 2");
 
-DeadCode;
\ No newline at end of file
+DeadCode;
